Package: BiocFHIR
Title: Illustration of FHIR ingestion and transformation using R
Version: 1.14.0
Date: 2022-11-29
Authors@R: 
    c(person(
        "Vincent", "Carey", role = c("aut", "cre"),
        email = "stvjc@channing.harvard.edu",
        comment = c(ORCID = "0000-0003-4046-0063")
    ))
Description: FHIR R4 bundles in JSON format are derived from https://synthea.mitre.org/downloads.
	Transformation inspired by a kaggle notebook published by Dr
	Alexander Scarlat, 
	https://www.kaggle.com/code/drscarlat/fhir-starter-parse-healthcare-bundles-into-tables.
	This is a very limited illustration of some basic parsing and reorganization
	processes.  Additional tooling will be required to move beyond the Synthea data illustrations.
License: Artistic-2.0
Encoding: UTF-8
Depends: R (>= 4.2)
Imports: DT, shiny, jsonlite, graph, tidyr, visNetwork, dplyr, utils,
        methods, BiocBaseUtils
Suggests: knitr, testthat, rjsoncons, igraph, BiocStyle
VignetteBuilder: knitr
biocViews: Infrastructure, DataImport, DataRepresentation
RoxygenNote: 7.3.2
URL: https://github.com/vjcitn/BiocFHIR
BugReports: https://github.com/vjcitn/BiocFHIR/issues
git_url: https://git.bioconductor.org/packages/BiocFHIR
git_branch: RELEASE_3_23
git_last_commit: ea4fb87
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 20:53:00 UTC; biocbuild
Author: Vincent Carey [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4046-0063>)
Maintainer: Vincent Carey <stvjc@channing.harvard.edu>
