# Generated by roxygen2: do not edit by hand

S3method(print,BiocFHIR.FHIRgraph)
S3method(print,FHIR.bundle)
export(FHIR_ResourceTypes)
export(FHIR_retention_schemas)
export(FHIRtabs)
export(add_procedures)
export(available_retention_schemas)
export(build_proccond_igraph)
export(display_proccond_igraph)
export(freq_app)
export(getHumanName)
export(make_condition_graph)
export(make_test_json_set)
export(process_AllergyIntolerance)
export(process_CarePlan)
export(process_Claim)
export(process_Condition)
export(process_Encounter)
export(process_Immunization)
export(process_MedicationRequest)
export(process_Observation)
export(process_Patient)
export(process_Procedure)
export(process_fhir_bundle)
export(stack_fhir)
export(summarise_bundles)
export(summary_selections)
import("graph", except=c("union", "edges", "intersection", "degree"))
import(dplyr)
import(shiny)
importFrom(BiocBaseUtils,selectSome)
importFrom(jsonlite,fromJSON)
importFrom(methods,new)
importFrom(tidyr,unnest)
importFrom(utils,data)
importFrom(utils,packageDescription)
importFrom(utils,unzip)
importFrom(visNetwork,visIgraph)
