#' collection of synthea FHIR documents ingested
#' @docType data
#' @examples
#' data("allin", package="BiocFHIR")
#' allin[[1]]
#' @format list
#' @usage data("allin", package = "BiocFHIR")
"allin"
