% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/app.R
\name{FHIRtabs}
\alias{FHIRtabs}
\title{table app}
\usage{
FHIRtabs()
}
\value{
No value returned.
}
\description{
table app
}
\examples{
if (interactive()) {
 FHIRtabs()
}
}
